@@ -112,7 +112,7 @@ def tableau_prets(request):
         derniere_date= max(min_max_date["M"], min_max_date["R"]) if \
             min_max_date["M"] else None
         date_unique = premiere_date == derniere_date
-        nouveaux_prets = Prets.objects.filter(
+        nouveaux_prets = les_prets.filter(
             Q(date_pret = derniere_date) | Q(date_retour = derniere_date))
         eleve = Eleves.objects.get(NomPrenomEleve = nomprenom)
         les_option = [
@@ -145,9 +145,10 @@ def tableau_prets(request):
         "pas_de_caution": _("<p>Attention : pas de caution en cours de validité.</p><p>On crée une nouvelle caution ?</p>"),
         "html_prets": render_to_string('gestion/tableau_prets.html', {
             "les_prets": les_prets.filter(date_retour = DATE111) \
-              if les_prets else "", # ne pas afficher les livres rendus !
-            "nouveaux_prets": nouveaux_prets,
+              if les_prets else [], # ne pas afficher les livres rendus !
+            "nouveaux_prets": len(nouveaux_prets),
             "date_unique": date_unique,
+            "date_prets": derniere_date,
             "eleve": eleve,
             "nomprenom": eleve.NomPrenomEleve if eleve else "",
             "classe": eleve.Lib_Structure if eleve else "",
@@ -519,6 +520,7 @@ def prete_livre(request):
         "messages" : messages,
         "tr_manuel" : tr_manuel,
         "nomprenom" : nomprenom,
+        "manuel": manuel.materiel.titre,
         "code": code,
     }
     return JsonResponse(data)
@@ -920,7 +922,7 @@ def purger_prets_go(request):
         date_retour__gt = DATE111)
     if date1:
         a_purger = a_purger.filter(
-            Date_Heure_Pret_Materiel__gt = date1)
+            date_pret__gt = date1)
     if date2:
         a_purger = a_purger.filter(
             date_retour__lt = date2)
@@ -1880,7 +1882,7 @@ def annule_caution_msg(request):
     POST contient le paramètre sans_accent
     """
     data = {
-        "html": _("<p>Dispenser {e} de caution ?</p>").format(e = requets.POST.get("sans_accent")),
+        "html": _("<p>Dispenser {e} de caution ?</p>").format(e = request.POST.get("sans_accent")),
         "title": _("Faire un statut « sans caution »"),
     }
     return JsonResponse(data)
