@@ -2036,15 +2036,23 @@ class Caution(models.Model):
 
 
     def __str__(self):
-        fin = " → " + self.rendue_le.strftime('%d/%m/%Y') if \
-            self.rendue_le > DATE111 else \
-            " (non rendue)"
         if self.somme_payee == 0:
-            return f"SANS CAUTION, {self.nom:35s}  {self.prenom:20s}, " + \
-                f"{self.date.strftime('%d/%m/%Y')}"
-        return f"Caution n° {self.numero:6d}, {self.nom:35s}  " + \
-            f"{self.prenom:20s} ({self.classe:7s}), " + \
-            f"date : {self.date.strftime('%d/%m/%Y') if self.date else 'None'}{fin}"
+            # Translators: N is a surname, p is a first name, d is a date
+            result = _("SANS CAUTION, {N:35s}  {p:20s}, {d}").format(
+                N=self.nom, p=self.prenom, d=self.date.strftime('%d/%m/%Y')
+            )
+        else:
+            fin = " → " + self.rendue_le.strftime('%d/%m/%Y') if \
+                self.rendue_le > DATE111 else \
+                _(" (non rendue)")
+            # Translators: N is a surname, p is a first name, c is a class name, d and f are dates
+            result = _("Caution n° {n:6d}, {N:35s} {p:2s} ({c:7s}), {d}{f}")\
+                .format(
+                    n=self.numero, N=self.nom, p=self.prenom, c=self.classe,
+                    d=self.date.strftime('%d/%m/%Y') if self.date else 'None',
+                    f=fin
+                )
+        return result
 
     @staticmethod
     def next_no_caution():
