@@ -27,14 +27,14 @@ from django.utils.translation import gettext_lazy as _
 from django.utils.translation import gettext
 from django.utils.translation import activate, get_language_info
 
-from .views_common import render_common, unaccent
+from .views_common import render_common
 # from .views_download import *
 # from .views_stats import *
 # from .odfviews import *
 from .models import Eleves, Materiel, LivreSupplement, Jeton, Inventaire, \
     Courriers, Classes, les_modeles, modeles_ordre, ETAT_MATERIEL_CHOIX, \
     Parametres, Prets, Niveaux, NOCLASS, Disciplines, Filieres, Series, \
-    TypeMateriel, Commandes, Personnels, Details
+    TypeMateriel, Commandes, Personnels, Details, sans_accent
 from .forms import Eleves_Form, Courriers_Form, donnees_utilisateur_Form, \
     Eleves_ancien_Form, Parametres_Form, Materiel_Form
 from .decorators import assure_jeton_valide, i18n
@@ -1307,7 +1307,7 @@ def qr_boutique(request):
          "code": abreges[a],
          "nombre": nombre_double_piles[a]}
         for a in sorted([ab for ab in abreges],
-                        key=lambda x: unaccent(x).lower())
+                        key=lambda x: sans_accent(x).lower())
     ]
     premiere_pile =  None
     livre_exemple =  None
